package com.fjhx.jpush.service.jpush.impl;


import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fjhx.jpush.entity.jpush.dto.JpushInfoDto;
import com.fjhx.jpush.entity.jpush.po.JpushInfo;
import com.fjhx.jpush.mapper.jpush.JpushInfoMapper;
import com.fjhx.jpush.service.jpush.JpushInfoService;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.stereotype.Service;

/**
 * <p>
 * 极光推送用户与设备绑定信息 服务实现类
 * </p>
 *
 * @author
 * @since 2023-10-08
 */
@Service
public class JpushInfoServiceImpl extends ServiceImpl<JpushInfoMapper, JpushInfo> implements JpushInfoService {

    /**
     * 极光推送用户与设备绑定信息绑定
     */
    @Override
    public void userBinding(JpushInfoDto jpushInfoDto) {
        if (ObjectUtil.isEmpty(jpushInfoDto.getRegistrationId())) {
            throw new ServiceException("设备注册id不能为空");
        }

        jpushInfoDto.setUserId(SecurityUtils.getUserId());

        //判断设备码是否已经绑定当前用户
        long count = this.count(q -> q
                .eq(JpushInfo::getUserId, jpushInfoDto.getUserId())
                .eq(JpushInfo::getRegistrationId, jpushInfoDto.getRegistrationId())
        );
        //如果没有绑定当前用户就绑定
        if (count == 0) {
            this.remove(q -> q.eq(JpushInfo::getRegistrationId, jpushInfoDto.getRegistrationId()));
            this.save(jpushInfoDto);
        }
    }

    /**
     * 极光推送用户与设备绑定信息解绑
     */
    @Override
    public void userUnBinding(JpushInfoDto jpushInfoDto) {
        if (ObjectUtil.isEmpty(jpushInfoDto.getRegistrationId())) {
            throw new ServiceException("设备注册id不能为空");
        }
        this.remove(q -> q.eq(JpushInfo::getRegistrationId, jpushInfoDto.getRegistrationId()));
    }

}
